@@ -2,38 +2,42 @@
 """
 
 from apyscript.expression import expression_file_util
-from apyscript.html import html_util
+from apyscript.type import value_util
+from apyscript.type.int import Int
+from apyscript.type.number_value_interface import NumberValueInterface
 from apyscript.type.variable_name_interface import VariableNameInterface
 from apyscript.validation import number_validation
 
 
 class XInterface(VariableNameInterface):
 
-    _x: int = 0
+    _x: Int = Int(value=0)
 
     @property
-    def x(self) -> int:
+    def x(self) -> Int:
         """
         Get x position.
 
         Returns
         -------
-        x : int
+        x : Int
             X position.
         """
-        return self._x
+        return value_util.get_copy(value=self._x)
 
     @x.setter
-    def x(self, value: int) -> None:
+    def x(self, value: Int) -> None:
         """
         Update x position.
 
         Parameters
         ----------
-        value : int
+        value : int or Int
             X potision value.
         """
-        number_validation.validate_integer(integer=value)
+        if not isinstance(value, NumberValueInterface):
+            number_validation.validate_integer(integer=value)
+            value = Int(value=value)
         self._x = value
         self._append_x_update_expression()
 
@@ -41,10 +45,10 @@ class XInterface(VariableNameInterface):
         """
         Append x position updating expression.
         """
+        value_str: str = value_util.get_value_str_for_expression(
+            value=self._x)
         expression: str = (
-            f'{self.variable_name}.x({self.x});'
+            f'{self.variable_name}.x({value_str});'
         )
-        expression = html_util.wrap_expression_by_script_tag(
-            expression=expression)
-        expression_file_util.append_expression(
+        expression_file_util.wrap_by_script_tag_and_append_expression(
             expression=expression)
